@@ -1,5 +1,5 @@
 
-# $Id: AP.pm,v 2.104 2005/02/19 23:29:42 Daddy Exp $
+# $Id: AP.pm,v 2.105 2007/05/19 23:49:38 Daddy Exp $
 
 =head1 NAME
 
@@ -17,8 +17,8 @@ WWW::Search::AP - backend for searching AP News at www.washingtonpost.com
 =head1 DESCRIPTION
 
 This class is a specialization of WWW::Search.  It handles making and
-interpreting searches on news at The AP section of The Washington Post
-F<http://www.washtech.com>.
+interpreting searches on AP news stories, courtesy of The Washington
+Post F<http://www.washingtonpost.com>.
 
 This class exports no public interface; all interaction should
 be done through L<WWW::Search> objects.
@@ -29,8 +29,7 @@ To make new back-ends, see L<WWW::Search>.
 
 =head1 NOTES
 
-This backend (and all its subclasses) only searches news stories from
-the last 14 days.
+This backend only searches news stories from the last 60 days.
 
 =head1 BUGS
 
@@ -47,14 +46,6 @@ THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
-=head1 VERSION HISTORY
-
-If it is not listed here, then it was not a meaningful nor released revision.
-
-=head2 2.01, 2002-03-12
-
-First public release.
-
 =cut
 
 #####################################################################
@@ -62,20 +53,19 @@ First public release.
 package WWW::Search::AP;
 
 use strict;
-use vars qw( @ISA $VERSION $MAINTAINER );
 
-use WWW::Search::WashPost;
+use base 'WWW::Search::WashPost';
 
-@ISA = qw( WWW::Search::WashPost );
+use vars qw( $VERSION $MAINTAINER );
 
-$VERSION = do { my @r = (q$Revision: 2.104 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.105 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 # private
 sub native_setup_search
   {
   my ($self, $sQuery, $rhOptions) = @_;
-  $rhOptions->{'source'} = 'APOnline';
+  $rhOptions->{'fa_1_sourcenavigator'} = 'AP';
   # All further work is done by our superclass, WWW::Search::WashPost:
   $self->SUPER::native_setup_search($sQuery, $rhOptions);
   } # native_setup_search
@@ -84,3 +74,4 @@ sub native_setup_search
 
 __END__
 
+http://www.washingtonpost.com/ac2/wp-dyn/NewsSearch?sa=as&sd=&ed=&sb=-1&st=turtle&blt=&fa_1_pagenavigator=&fa_1_sourcenavigator=AP&daterange=0&specificMonth=5&specificDay=18&specificYear=2007&FromRangeMonth=3&FromRangeDay=19&FromRangeYear=2007&ToRangeMonth=5&ToRangeDay=18&ToRangeYear=2007&sb2=1&x=18&y=12
